@@ -1,13 +1,9 @@
-# coding: utf-8
-
 """Library to build speech synthesis systems designed for prototyping.
 
 https://github.com/r9y9/nnmnkwii
 """
 
-from __future__ import division, print_function, absolute_import
-
 try:
-    from .version import __version__
+    from .version import __version__  # NOQA
 except ImportError:
     raise ImportError("BUG: version.py doesn't exist. Please file a bug report.")
