@@ -1,5 +1,3 @@
-# coding: utf-8
-
 # Part of code here is adapted from Merlin. Their license follows:
 ##########################################################################
 #           The Neural Network (NN) based Speech Synthesis System
@@ -39,11 +37,10 @@
 #  ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF
 #  THIS SOFTWARE.
 ##########################################################################
-
-from __future__ import division, print_function, absolute_import
+# fmt: off
 
 import numpy as np
-
+from nnmnkwii.frontend import NOTE_MAPPING
 from nnmnkwii.io import hts
 
 
@@ -53,35 +50,34 @@ def get_frame_feature_size(subphone_features="full"):
         return 0
     subphone_features = subphone_features.strip().lower()
     if subphone_features == "none":
-        raise ValueError(
-            "subphone_features = 'none' is deprecated, use None instead")
-    if subphone_features == 'full':
+        raise ValueError("subphone_features = 'none' is deprecated, use None instead")
+    if subphone_features == "full":
         return 9  # zhizheng's original 5 state features + 4 phoneme features
-    elif subphone_features == 'minimal_frame':
+    elif subphone_features == "minimal_frame":
         # the minimal features necessary to go from a state-level to
         # frame-level model
         return 2
-    elif subphone_features == 'state_only':
+    elif subphone_features == "state_only":
         return 1  # this is equivalent to a state-based system
-    elif subphone_features == 'frame_only':
+    elif subphone_features == "frame_only":
         # this is equivalent to a frame-based system without relying on
         # state-features
         return 1
-    elif subphone_features == 'uniform_state':
+    elif subphone_features == "uniform_state":
         # this is equivalent to a frame-based system with uniform
         # state-features
         return 2
-    elif subphone_features == 'minimal_phoneme':
+    elif subphone_features == "minimal_phoneme":
         # this is equivalent to a frame-based system with minimal features
         return 3
-    elif subphone_features == 'coarse_coding':
+    elif subphone_features == "coarse_coding":
         # this is equivalent to a frame-based positioning system reported in
         # Heiga Zen's work
         return 4
     else:
         raise ValueError(
-            'Unknown value for subphone_features: %s' % (subphone_features))
-    assert False
+            "Unknown value for subphone_features: %s" % (subphone_features)
+        )
 
 
 def compute_coarse_coding_features(num_states=3, npoints=600):
@@ -100,6 +96,7 @@ def compute_coarse_coding_features(num_states=3, npoints=600):
     sigma = 0.4
 
     from scipy.stats import norm
+
     cc_features[0, :] = norm(mu1, sigma).pdf(x1)
     cc_features[1, :] = norm(mu2, sigma).pdf(x2)
     cc_features[2, :] = norm(mu3, sigma).pdf(x3)
@@ -125,10 +122,13 @@ def extract_coarse_coding_features_relative(cc_features, phone_duration):
 
 def pattern_matching_binary(binary_dict, label):
     dict_size = len(binary_dict)
-    lab_binary_vector = np.zeros((1, dict_size), dtype=np.int)
+    lab_binary_vector = np.zeros((1, dict_size), dtype=int)
 
     for i in range(dict_size):
         current_question_list = binary_dict[i]
+        # NOTE: newer version returns tuple of (name, question)
+        if isinstance(current_question_list, tuple):
+            current_question_list = current_question_list[1]
         binary_flag = 0
         for iq in range(len(current_question_list)):
             current_compiled = current_question_list[iq]
@@ -142,32 +142,46 @@ def pattern_matching_binary(binary_dict, label):
     return lab_binary_vector
 
 
-def pattern_matching_continous_position(continuous_dict, label):
-    dict_size = len(continuous_dict)
+def pattern_matching_continous_position(numeric_dict, label):
+    dict_size = len(numeric_dict)
 
     lab_continuous_vector = np.zeros((1, dict_size), dtype=np.float32)
     for i in range(dict_size):
+        current_compiled = numeric_dict[i]
 
-        continuous_value = -1.0
-
-        current_compiled = continuous_dict[i]
+        # NOTE: newer version returns tuple of (name, question)
+        if isinstance(current_compiled, tuple):
+            current_compiled = current_compiled[1]
+        if "([-\\d]+)" in current_compiled.pattern:
+            continuous_value = -50.0
+        else:
+            continuous_value = -1.0
 
         ms = current_compiled.search(label)
         if ms is not None:
             continuous_value = ms.group(1)
+            if continuous_value in NOTE_MAPPING:
+                continuous_value = NOTE_MAPPING[continuous_value]
+            if isinstance(continuous_value, str):
+                if continuous_value.startswith("p"):
+                    continuous_value = int(continuous_value[1:])
+                elif continuous_value.startswith("m"):
+                    continuous_value = -int(continuous_value[1:])
 
         lab_continuous_vector[0, i] = continuous_value
 
     return lab_continuous_vector
 
 
-def load_labels_with_phone_alignment(hts_labels,
-                                     binary_dict,
-                                     continuous_dict,
-                                     subphone_features=None,
-                                     add_frame_features=False,
-                                     frame_shift_in_micro_sec=50000):
-    dict_size = len(binary_dict) + len(continuous_dict)
+def load_labels_with_phone_alignment(
+    hts_labels,
+    binary_dict,
+    numeric_dict,
+    subphone_features=None,
+    add_frame_features=False,
+    frame_shift=50000,
+):
+    dict_size = len(binary_dict) + len(numeric_dict)
     frame_feature_size = get_frame_feature_size(subphone_features)
     dimension = frame_feature_size + dict_size
 
@@ -182,90 +196,99 @@ def load_labels_with_phone_alignment(hts_labels,
     if subphone_features == "coarse_coding":
         cc_features = compute_coarse_coding_features()
 
-    for idx, (start_time, end_time, full_label) in enumerate(hts_labels):
-        frame_number = int(end_time / frame_shift_in_micro_sec) - int(start_time / frame_shift_in_micro_sec)
+    for _, (start_time, end_time, full_label) in enumerate(hts_labels):
+        frame_number = int(end_time / frame_shift) - int(start_time / frame_shift)
 
-        label_binary_vector = pattern_matching_binary(
-            binary_dict, full_label)
+        label_binary_vector = pattern_matching_binary(binary_dict, full_label)
 
         # if there is no CQS question, the label_continuous_vector will
         # become to empty
         label_continuous_vector = pattern_matching_continous_position(
-            continuous_dict, full_label)
+            numeric_dict, full_label
+        )
         label_vector = np.concatenate(
-            [label_binary_vector, label_continuous_vector], axis=1)
+            [label_binary_vector, label_continuous_vector], axis=1
+        )
 
         if subphone_features == "coarse_coding":
-            cc_feat_matrix = extract_coarse_coding_features_relative(cc_features,
-                                                                     frame_number)
+            cc_feat_matrix = extract_coarse_coding_features_relative(
+                cc_features, frame_number
+            )
 
         if add_frame_features:
             current_block_binary_array = np.zeros(
-                (frame_number, dict_size + frame_feature_size))
+                (frame_number, dict_size + frame_feature_size)
+            )
             for i in range(frame_number):
-                current_block_binary_array[i,
-                                           0:dict_size] = label_vector
+                current_block_binary_array[i, 0:dict_size] = label_vector
 
-                if subphone_features == 'minimal_phoneme':
+                if subphone_features == "minimal_phoneme":
                     # features which distinguish frame position in phoneme
                     # fraction through phone forwards
-                    current_block_binary_array[i, dict_size] = float(
-                        i + 1) / float(frame_number)
+                    current_block_binary_array[i, dict_size] = float(i + 1) / float(
+                        frame_number
+                    )
                     # fraction through phone backwards
                     current_block_binary_array[i, dict_size + 1] = float(
-                        frame_number - i) / float(frame_number)
+                        frame_number - i
+                    ) / float(frame_number)
                     # phone duration
-                    current_block_binary_array[i,
-                                               dict_size + 2] = float(frame_number)
+                    current_block_binary_array[i, dict_size + 2] = float(frame_number)
 
-                elif subphone_features == 'coarse_coding':
+                elif subphone_features == "coarse_coding":
                     # features which distinguish frame position in phoneme
                     # using three continous numerical features
-                    current_block_binary_array[i,
-                                               dict_size + 0] = cc_feat_matrix[i, 0]
-                    current_block_binary_array[i,
-                                               dict_size + 1] = cc_feat_matrix[i, 1]
-                    current_block_binary_array[i,
-                                               dict_size + 2] = cc_feat_matrix[i, 2]
-                    current_block_binary_array[i,
-                                               dict_size + 3] = float(frame_number)
+                    current_block_binary_array[i, dict_size + 0] = cc_feat_matrix[i, 0]
+                    current_block_binary_array[i, dict_size + 1] = cc_feat_matrix[i, 1]
+                    current_block_binary_array[i, dict_size + 2] = cc_feat_matrix[i, 2]
+                    current_block_binary_array[i, dict_size + 3] = float(frame_number)
 
                 elif subphone_features is None:
                     pass
                 else:
                     raise ValueError(
-                        "Combination of subphone_features and add_frame_features is not supported: {}, {}".format(
-                            subphone_features, add_frame_features))
-
-            label_feature_matrix[label_feature_index:label_feature_index +
-                                 frame_number, ] = current_block_binary_array
+                        "Combination of subphone_features and add_frame_features "
+                        "is not supported: {}, {}".format(
+                            subphone_features, add_frame_features
+                        )
+                    )
+            label_feature_matrix[
+                label_feature_index : label_feature_index + frame_number,
+            ] = current_block_binary_array
             label_feature_index = label_feature_index + frame_number
 
         elif subphone_features is None:
             current_block_binary_array = label_vector
-            label_feature_matrix[label_feature_index:label_feature_index +
-                                 1, ] = current_block_binary_array
+            label_feature_matrix[
+                label_feature_index : label_feature_index + 1,
+            ] = current_block_binary_array
             label_feature_index = label_feature_index + 1
         else:
             pass
 
     # omg
     if label_feature_index == 0:
-        raise ValueError("Combination of subphone_features and add_frame_features is not supported: {}, {}".format(
-            subphone_features, add_frame_features))
+        raise ValueError(
+            "Combination of subphone_features and add_frame_features is not supported"
+            " : {}, {}".format(subphone_features, add_frame_features)
+        )
 
-    label_feature_matrix = label_feature_matrix[0:label_feature_index, ]
+    label_feature_matrix = label_feature_matrix[
+        0:label_feature_index,
+    ]
 
     return label_feature_matrix
 
 
-def load_labels_with_state_alignment(hts_labels,
-                                     binary_dict,
-                                     continuous_dict,
-                                     subphone_features=None,
-                                     add_frame_features=False,
-                                     frame_shift_in_micro_sec=50000):
-    dict_size = len(binary_dict) + len(continuous_dict)
+def load_labels_with_state_alignment(
+    hts_labels,
+    binary_dict,
+    numeric_dict,
+    subphone_features=None,
+    add_frame_features=False,
+    frame_shift=50000,
+):
+    dict_size = len(binary_dict) + len(numeric_dict)
     frame_feature_size = get_frame_feature_size(subphone_features)
     dimension = frame_feature_size + dict_size
 
@@ -283,8 +306,7 @@ def load_labels_with_state_alignment(hts_labels,
 
     phone_duration = 0
     state_duration_base = 0
-    for current_index, (start_time, end_time,
-                        full_label) in enumerate(hts_labels):
+    for current_index, (start_time, end_time, full_label) in enumerate(hts_labels):
         # remove state information [k]
         assert full_label[-1] == "]"
         full_label_length = len(full_label) - 3
@@ -294,138 +316,155 @@ def load_labels_with_state_alignment(hts_labels,
         state_index_backward = state_number + 1 - state_index
         full_label = full_label[0:full_label_length]
 
-        frame_number = (end_time - start_time) // frame_shift_in_micro_sec
+        frame_number = (end_time - start_time) // frame_shift
 
         if state_index == 1:
             current_frame_number = 0
             phone_duration = frame_number
             state_duration_base = 0
 
-            label_binary_vector = pattern_matching_binary(
-                binary_dict, full_label)
+            label_binary_vector = pattern_matching_binary(binary_dict, full_label)
 
             # if there is no CQS question, the label_continuous_vector will
             # become to empty
             label_continuous_vector = pattern_matching_continous_position(
-                continuous_dict, full_label)
+                numeric_dict, full_label
+            )
             label_vector = np.concatenate(
-                [label_binary_vector, label_continuous_vector], axis=1)
+                [label_binary_vector, label_continuous_vector], axis=1
+            )
 
             for i in range(state_number - 1):
                 s, e, _ = hts_labels[current_index + i + 1]
-                phone_duration += (e - s) // frame_shift_in_micro_sec
+                phone_duration += (e - s) // frame_shift
 
             if subphone_features == "coarse_coding":
                 cc_feat_matrix = extract_coarse_coding_features_relative(
-                    cc_features, phone_duration)
+                    cc_features, phone_duration
+                )
 
         if add_frame_features:
             current_block_binary_array = np.zeros(
-                (frame_number, dict_size + frame_feature_size))
+                (frame_number, dict_size + frame_feature_size)
+            )
             for i in range(frame_number):
-                current_block_binary_array[i,
-                                           0: dict_size] = label_vector
+                current_block_binary_array[i, 0:dict_size] = label_vector
 
-                if subphone_features == 'full':
+                if subphone_features == "full":
                     # Zhizheng's original 9 subphone features:
                     # fraction through state (forwards)
-                    current_block_binary_array[i, dict_size] = float(
-                        i + 1) / float(frame_number)
+                    current_block_binary_array[i, dict_size] = float(i + 1) / float(
+                        frame_number
+                    )
                     # fraction through state (backwards)
                     current_block_binary_array[i, dict_size + 1] = float(
-                        frame_number - i) / float(frame_number)
+                        frame_number - i
+                    ) / float(frame_number)
                     # length of state in frames
-                    current_block_binary_array[i,
-                                               dict_size + 2] = float(frame_number)
+                    current_block_binary_array[i, dict_size + 2] = float(frame_number)
                     # state index (counting forwards)
-                    current_block_binary_array[i,
-                                               dict_size + 3] = float(state_index)
+                    current_block_binary_array[i, dict_size + 3] = float(state_index)
                     # state index (counting backwards)
-                    current_block_binary_array[i, dict_size +
-                                               4] = float(state_index_backward)
+                    current_block_binary_array[i, dict_size + 4] = float(
+                        state_index_backward
+                    )
 
                     # length of phone in frames
-                    current_block_binary_array[i,
-                                               dict_size + 5] = float(phone_duration)
+                    current_block_binary_array[i, dict_size + 5] = float(phone_duration)
                     # fraction of the phone made up by current state
-                    current_block_binary_array[i, dict_size +
-                                               6] = float(frame_number) / float(phone_duration)
+                    current_block_binary_array[i, dict_size + 6] = float(
+                        frame_number
+                    ) / float(phone_duration)
                     # fraction through phone (backwards)
                     current_block_binary_array[i, dict_size + 7] = float(
-                        phone_duration - i - state_duration_base) / float(phone_duration)
+                        phone_duration - i - state_duration_base
+                    ) / float(phone_duration)
                     # fraction through phone (forwards)
                     current_block_binary_array[i, dict_size + 8] = float(
-                        state_duration_base + i + 1) / float(phone_duration)
+                        state_duration_base + i + 1
+                    ) / float(phone_duration)
 
-                elif subphone_features == 'state_only':
+                elif subphone_features == "state_only":
                     # features which only distinguish state:
                     current_block_binary_array[i, dict_size] = float(
-                        state_index)  # state index (counting forwards)
+                        state_index
+                    )  # state index (counting forwards)
 
-                elif subphone_features == 'frame_only':
+                elif subphone_features == "frame_only":
                     # features which distinguish frame position in phoneme:
                     current_frame_number += 1
                     # fraction through phone (counting forwards)
                     current_block_binary_array[i, dict_size] = float(
-                        current_frame_number) / float(phone_duration)
+                        current_frame_number
+                    ) / float(phone_duration)
 
-                elif subphone_features == 'uniform_state':
+                elif subphone_features == "uniform_state":
                     # features which distinguish frame position in phoneme:
                     current_frame_number += 1
                     # fraction through phone (counting forwards)
                     current_block_binary_array[i, dict_size] = float(
-                        current_frame_number) / float(phone_duration)
+                        current_frame_number
+                    ) / float(phone_duration)
                     new_state_index = max(
-                        1, round(float(current_frame_number) / float(phone_duration) * 5))
+                        1,
+                        round(float(current_frame_number) / float(phone_duration) * 5),
+                    )
                     # state index (counting forwards)
-                    current_block_binary_array[i,
-                                               dict_size + 1] = float(new_state_index)
+                    current_block_binary_array[i, dict_size + 1] = float(
+                        new_state_index
+                    )
 
                 elif subphone_features == "coarse_coding":
                     # features which distinguish frame position in phoneme
                     # using three continous numerical features
-                    current_block_binary_array[i, dict_size +
-                                               0] = cc_feat_matrix[current_frame_number, 0]
-                    current_block_binary_array[i, dict_size +
-                                               1] = cc_feat_matrix[current_frame_number, 1]
-                    current_block_binary_array[i, dict_size +
-                                               2] = cc_feat_matrix[current_frame_number, 2]
-                    current_block_binary_array[i,
-                                               dict_size + 3] = float(phone_duration)
+                    current_block_binary_array[i, dict_size + 0] = cc_feat_matrix[
+                        current_frame_number, 0
+                    ]
+                    current_block_binary_array[i, dict_size + 1] = cc_feat_matrix[
+                        current_frame_number, 1
+                    ]
+                    current_block_binary_array[i, dict_size + 2] = cc_feat_matrix[
+                        current_frame_number, 2
+                    ]
+                    current_block_binary_array[i, dict_size + 3] = float(phone_duration)
                     current_frame_number += 1
 
-                elif subphone_features == 'minimal_frame':
+                elif subphone_features == "minimal_frame":
                     # features which distinguish state and minimally frame
                     # position in state:
-                    current_block_binary_array[i, dict_size] = float(
-                        i + 1) / float(frame_number)  # fraction through state (forwards)
+                    current_block_binary_array[i, dict_size] = float(i + 1) / float(
+                        frame_number
+                    )  # fraction through state (forwards)
                     # state index (counting forwards)
-                    current_block_binary_array[i,
-                                               dict_size + 1] = float(state_index)
+                    current_block_binary_array[i, dict_size + 1] = float(state_index)
                 elif subphone_features is None:
                     pass
                 else:
-                    assert False
+                    raise AssertionError()
 
-            label_feature_matrix[label_feature_index:label_feature_index +
-                                 frame_number] = current_block_binary_array
+            label_feature_matrix[
+                label_feature_index : label_feature_index + frame_number
+            ] = current_block_binary_array
             label_feature_index = label_feature_index + frame_number
-        elif subphone_features == 'state_only' and state_index == state_number:
+        elif subphone_features == "state_only" and state_index == state_number:
             # TODO: this pass seems not working
             current_block_binary_array = np.zeros(
-                (state_number, dict_size + frame_feature_size))
+                (state_number, dict_size + frame_feature_size)
+            )
             for i in range(state_number):
-                current_block_binary_array[i,
-                                           0:dict_size] = label_vector
+                current_block_binary_array[i, 0:dict_size] = label_vector
                 current_block_binary_array[i, dict_size] = float(
-                    i + 1)  # state index (counting forwards)
-            label_feature_matrix[label_feature_index:label_feature_index +
-                                 state_number, ] = current_block_binary_array
+                    i + 1
+                )  # state index (counting forwards)
+            label_feature_matrix[
+                label_feature_index : label_feature_index + state_number,
+            ] = current_block_binary_array
             label_feature_index = label_feature_index + state_number
         elif subphone_features is None and state_index == state_number:
             current_block_binary_array = label_vector
-            label_feature_matrix[label_feature_index:label_feature_index +
-                                 1, ] = current_block_binary_array
+            label_feature_matrix[
+                label_feature_index : label_feature_index + 1,
+            ] = current_block_binary_array
             label_feature_index = label_feature_index + 1
         else:
             pass
@@ -434,10 +473,14 @@ def load_labels_with_state_alignment(hts_labels,
 
     # omg
     if label_feature_index == 0:
-        raise ValueError("Combination of subphone_features and add_frame_features is not supported: {}, {}".format(
-            subphone_features, add_frame_features))
+        raise ValueError(
+            "Combination of subphone_features and add_frame_features"
+            " is not supported: {}, {}".format(subphone_features, add_frame_features)
+        )
 
-    label_feature_matrix = label_feature_matrix[0:label_feature_index, ]
+    label_feature_matrix = label_feature_matrix[
+        0:label_feature_index,
+    ]
     return label_feature_matrix
 
 
@@ -457,7 +500,7 @@ def linguistic_features(hts_labels, *args, **kwargs):
     Args:
         hts_label (hts.HTSLabelFile): Input full-context label file
         binary_dict (dict): Dictionary used to extract binary features
-        continuous_dict (dict): Dictionary used to extrract continuous features
+        numeric_dict (dict): Dictionary used to extrract continuous features
         subphone_features (dict): Type of sub-phone features. According
           to the Merlin's source code, None, ``full``, ``state_only``,
           ``frame_only``, ``uniform_state``, ``minimal_phoneme`` and
@@ -466,7 +509,7 @@ def linguistic_features(hts_labels, *args, **kwargs):
           this library. Default is None.
         add_frame_features (dict): Whether add frame-level features or not.
           Default is False.
-        frame_shift_in_micro_sec (int) : Frame shift of alignment in micro seconds.
+        frame_shift (int) : Frame shift of alignment in 100ns units.
 
     Returns:
         numpy.ndarray: Numpy array representation of linguistic features.
@@ -478,12 +521,12 @@ def linguistic_features(hts_labels, *args, **kwargs):
         >>> from nnmnkwii.io import hts
         >>> from nnmnkwii.util import example_label_file, example_question_file
         >>> labels = hts.load(example_label_file(phone_level=False))
-        >>> binary_dict, continuous_dict = hts.load_question_set(example_question_file())
-        >>> features = fe.linguistic_features(labels, binary_dict, continuous_dict,
+        >>> binary_dict, numeric_dict = hts.load_question_set(example_question_file())
+        >>> features = fe.linguistic_features(labels, binary_dict, numeric_dict,
         ...     subphone_features="full", add_frame_features=True)
         >>> features.shape
         (615, 425)
-        >>> features = fe.linguistic_features(labels, binary_dict, continuous_dict,
+        >>> features = fe.linguistic_features(labels, binary_dict, numeric_dict,
         ...     subphone_features=None, add_frame_features=False)
         >>> features.shape
         (40, 416)
@@ -494,12 +537,12 @@ def linguistic_features(hts_labels, *args, **kwargs):
         >>> from nnmnkwii.io import hts
         >>> from nnmnkwii.util import example_label_file, example_question_file
         >>> labels = hts.load(example_label_file(phone_level=True))
-        >>> binary_dict, continuous_dict = hts.load_question_set(example_question_file())
-        >>> features = fe.linguistic_features(labels, binary_dict, continuous_dict,
+        >>> binary_dict, numeric_dict = hts.load_question_set(example_question_file())
+        >>> features = fe.linguistic_features(labels, binary_dict, numeric_dict,
         ...     subphone_features="coarse_coding", add_frame_features=True)
         >>> features.shape
         (615, 420)
-        >>> features = fe.linguistic_features(labels, binary_dict, continuous_dict,
+        >>> features = fe.linguistic_features(labels, binary_dict, numeric_dict,
         ...     subphone_features=None, add_frame_features=False)
         >>> features.shape
         (40, 416)
@@ -511,11 +554,13 @@ def linguistic_features(hts_labels, *args, **kwargs):
         return load_labels_with_phone_alignment(hts_labels, *args, **kwargs)
 
 
-def extract_dur_from_state_alignment_labels(hts_labels,
-                                            feature_type="numerical",
-                                            unit_size="state",
-                                            feature_size="phoneme",
-                                            frame_shift_in_micro_sec=50000):
+def extract_dur_from_state_alignment_labels(
+    hts_labels,
+    feature_type="numerical",
+    unit_size="state",
+    feature_size="phoneme",
+    frame_shift=50000,
+):
     if feature_type not in ["binary", "numerical"]:
         raise ValueError("Not supported")
     if unit_size not in ["phoneme", "state"]:
@@ -525,33 +570,29 @@ def extract_dur_from_state_alignment_labels(hts_labels,
 
     dur_dim = hts_labels.num_states() if unit_size == "state" else 1
     if feature_size == "phoneme":
-        dur_feature_matrix = np.empty(
-            (hts_labels.num_phones(), dur_dim), dtype=np.int)
+        dur_feature_matrix = np.empty((hts_labels.num_phones(), dur_dim), dtype=int)
     else:
-        dur_feature_matrix = np.empty(
-            (hts_labels.num_frames(), dur_dim), dtype=np.int)
+        dur_feature_matrix = np.empty((hts_labels.num_frames(), dur_dim), dtype=int)
 
     current_dur_array = np.zeros((dur_dim, 1))
     state_number = hts_labels.num_states()
     dur_dim = state_number
 
     dur_feature_index = 0
-    for current_index, (start_time, end_time,
-                        full_label) in enumerate(hts_labels):
+    for current_index, (start_time, end_time, full_label) in enumerate(hts_labels):
         # remove state information [k]
         full_label_length = len(full_label) - 3
         state_index = full_label[full_label_length + 1]
         state_index = int(state_index) - 1
 
-        frame_number = (
-            end_time - start_time) // frame_shift_in_micro_sec
+        frame_number = (end_time - start_time) // frame_shift
 
         if state_index == 1:
             phone_duration = frame_number
 
             for i in range(state_number - 1):
                 s, e, _ = hts_labels[current_index + i + 1]
-                phone_duration += (e - s) // frame_shift_in_micro_sec
+                phone_duration += (e - s) // frame_shift
 
         if feature_type == "binary":
             current_block_array = np.zeros((frame_number, 1))
@@ -561,7 +602,7 @@ def extract_dur_from_state_alignment_labels(hts_labels,
                 if state_index == state_number:
                     current_block_array[-1] = 1
             else:
-                assert False
+                raise AssertionError()
         elif feature_type == "numerical":
             if unit_size == "state":
                 current_dur_array[current_index % 5] = frame_number
@@ -569,33 +610,40 @@ def extract_dur_from_state_alignment_labels(hts_labels,
                     current_block_array = current_dur_array.transpose()
                 if feature_size == "frame":
                     current_block_array = np.tile(
-                        current_dur_array.transpose(), (frame_number, 1))
+                        current_dur_array.transpose(), (frame_number, 1)
+                    )
             elif unit_size == "phoneme":
                 current_block_array = np.array([phone_duration])
             else:
-                assert False
+                raise AssertionError()
 
         # writing into dur_feature_matrix
         if feature_size == "frame":
-            dur_feature_matrix[dur_feature_index:dur_feature_index +
-                               frame_number, ] = current_block_array
+            dur_feature_matrix[
+                dur_feature_index : dur_feature_index + frame_number,
+            ] = current_block_array
             dur_feature_index = dur_feature_index + frame_number
         elif feature_size == "phoneme" and state_index == state_number:
-            dur_feature_matrix[dur_feature_index:dur_feature_index +
-                               1, ] = current_block_array
+            dur_feature_matrix[
+                dur_feature_index : dur_feature_index + 1,
+            ] = current_block_array
             dur_feature_index = dur_feature_index + 1
         else:
             pass
 
-    # dur_feature_matrix = dur_feature_matrix[0:dur_feature_index, ]
+    dur_feature_matrix = dur_feature_matrix[
+        0:dur_feature_index,
+    ]
     return dur_feature_matrix
 
 
-def extract_dur_from_phone_alignment_labels(hts_labels,
-                                            feature_type="numerical",
-                                            unit_size="phoneme",
-                                            feature_size="phoneme",
-                                            frame_shift_in_micro_sec=50000):
+def extract_dur_from_phone_alignment_labels(
+    hts_labels,
+    feature_type="numerical",
+    unit_size="phoneme",
+    feature_size="phoneme",
+    frame_shift=50000,
+):
     if feature_type not in ["binary", "numerical"]:
         raise ValueError("Not supported")
     if unit_size != "phoneme":
@@ -603,14 +651,12 @@ def extract_dur_from_phone_alignment_labels(hts_labels,
     if feature_size not in ["phoneme", "frame"]:
         raise ValueError("Not supported")
     if feature_size == "phoneme":
-        dur_feature_matrix = np.empty(
-            (hts_labels.num_phones(), 1), dtype=np.int)
+        dur_feature_matrix = np.empty((hts_labels.num_phones(), 1), dtype=int)
     else:
-        dur_feature_matrix = np.empty(
-            (hts_labels.num_frames(), 1), dtype=np.int)
+        dur_feature_matrix = np.empty((hts_labels.num_frames(), 1), dtype=int)
     dur_feature_index = 0
-    for current_index, (start_time, end_time, _) in enumerate(hts_labels):
-        frame_number = (end_time - start_time) / frame_shift_in_micro_sec
+    for _, (start_time, end_time, _) in enumerate(hts_labels):
+        frame_number = (end_time - start_time) / frame_shift
 
         phone_duration = frame_number
 
@@ -620,21 +666,23 @@ def extract_dur_from_phone_alignment_labels(hts_labels,
         elif feature_type == "numerical":
             current_block_array = np.array([phone_duration])
         else:
-            assert False
+            raise AssertionError()
 
         # writing into dur_feature_matrix
         if feature_size == "frame":
-            dur_feature_matrix[dur_feature_index:dur_feature_index +
-                               frame_number] = current_block_array
+            dur_feature_matrix[
+                dur_feature_index : dur_feature_index + frame_number
+            ] = current_block_array
             dur_feature_index = dur_feature_index + frame_number
         elif feature_size == "phoneme":
-            dur_feature_matrix[dur_feature_index:dur_feature_index +
-                               1] = current_block_array
+            dur_feature_matrix[
+                dur_feature_index : dur_feature_index + 1
+            ] = current_block_array
             dur_feature_index = dur_feature_index + 1
         else:
-            assert False
+            raise AssertionError()
 
-    # dur_feature_matrix = dur_feature_matrix[0:dur_feature_index]
+    dur_feature_matrix = dur_feature_matrix[0:dur_feature_index]
     return dur_feature_matrix
 
 
@@ -655,7 +703,7 @@ def duration_features(hts_labels, *args, **kwargs):
           phone-level alignment is ``state`` and ``phoneme``, respectively.
         feature_size (str): ``frame`` or ``phoneme``. Default is ``phoneme``.
           ``frame`` is only supported for state-level alignments.
-        frame_shift_in_micro_sec (int) : Frame shift of alignment in micro seconds.
+        frame_shift (int) : Frame shift of alignment in 100ns units.
 
     Returns:
         numpy.ndarray: numpy array representation of duration features.
@@ -683,8 +731,6 @@ def duration_features(hts_labels, *args, **kwargs):
 
     """
     if hts_labels.is_state_alignment_label():
-        return extract_dur_from_state_alignment_labels(
-            hts_labels, *args, **kwargs)
+        return extract_dur_from_state_alignment_labels(hts_labels, *args, **kwargs)
     else:
-        return extract_dur_from_phone_alignment_labels(
-            hts_labels, *args, **kwargs)
+        return extract_dur_from_phone_alignment_labels(hts_labels, *args, **kwargs)
